# python-genbadge

*Define fields in python classes. Easily.*

[![Python versions](https://img.shields.io/pypi/pyversions/genbadge.svg)](https://pypi.python.org/pypi/genbadge/) [![Build Status](https://github.com/smarie/python-genbadge/actions/workflows/base.yml/badge.svg)](https://github.com/smarie/python-genbadge/actions/workflows/base.yml) [![Tests Status](https://smarie.github.io/python-genbadge/reports/junit/junit-badge.svg?dummy=8484744)](https://smarie.github.io/python-genbadge/reports/junit/report.html) [![Coverage Status](https://smarie.github.io/python-genbadge/reports/coverage/coverage-badge.svg?dummy=8484744)](https://smarie.github.io/python-genbadge/reports/coverage/index.html) [![Flake8 Status](https://smarie.github.io/python-genbadge/reports/flake8/flake8-badge.svg?dummy=8484744)](https://smarie.github.io/python-genbadge/reports/flake8/index.html)

[![Documentation](https://img.shields.io/badge/doc-latest-blue.svg)](https://smarie.github.io/python-genbadge/) [![PyPI](https://img.shields.io/pypi/v/genbadge.svg)](https://pypi.python.org/pypi/genbadge/) [![Downloads](https://pepy.tech/badge/genbadge)](https://pepy.tech/project/genbadge) [![Downloads per week](https://pepy.tech/badge/genbadge/week)](https://pepy.tech/project/genbadge) [![GitHub stars](https://img.shields.io/github/stars/smarie/python-genbadge.svg)](https://github.com/smarie/python-genbadge/stargazers) [![codecov](https://codecov.io/gh/smarie/python-genbadge/branch/main/graph/badge.svg)](https://codecov.io/gh/smarie/python-genbadge)

The documentation for users is available here: [https://smarie.github.io/python-genbadge/](https://smarie.github.io/python-genbadge/)

A readme for developers is available here: [https://github.com/smarie/python-genbadge](https://github.com/smarie/python-genbadge)
